@@ -1,6 +1,8 @@
 import argparse
 from os.path import abspath, dirname
 from inspect import getfile, currentframe
+from urllib.request import Request, urlopen
+import json
 
 
 def set_key(key):
@@ -10,6 +12,12 @@ def set_key(key):
         f.write("OPENAI_KEY=\"" + key + "\"")
 
 
+def version():
+    """Return version information"""
+    with urlopen(Request("https://pypi.org/pypi/chatgdb/json"), timeout=10) as f:
+        return json.load(f)["info"]["version"]
+
+
 def main():
     parser = argparse.ArgumentParser(
         description="Configure ChatGDB, the GDB chatbot",
@@ -19,6 +27,12 @@ def main():
         "--key",
         type=str,
         help="Provide an api key for ChatGDB")
+    parser.add_argument(
+        '-v',
+        "--version",
+        action="version",
+        version="%(prog)s " + version(),
+        help="Print the version of ChatGDB")
 
     args = parser.parse_args()
     if args.key:
